"""scenario texts module"""
# player
PLAYER_NAME = "Player"
PLAYER_DESCRIPTION = "A slim person with fiery blue eyes and pitch-black hair."

#########################################################################

# cellar
CELLAR_NAME = "Cellar"
CELLAR_DESCRIPTION = "A dusty abandoned cellar with an unusable broken staircase leading up.\n"
CELLAR_BRIEF = "You find yourself in a repurposed cellar. There are dustparticals dancing rhythmically around you; there is magic in the air."

# cellar altar
CELLAR_ALTAR_NAME = "altar"
CELLAR_ALTAR_DESCRIPTION = "A large round object covered in a tarp."

# cellar skeleton
CELLAR_SKELETON_NAME = "skeleton"
CELLAR_SKELETON_DESCRIPTION = "A skeleton."

#########################################################################

# dining room
DINING_ROOM_NAME = "Dining Room"
DINING_ROOM_DESCRIPTION = "A large L shaped room with two closed windows illuminating a homey interior."
DINING_ROOM_BRIEF = "As you enter the room you get greeted by the warmth of a crackling fireplace in the corner and the smell of a fresh breakfast."

# rope
ROPE_NAME = "rope"
ROPE_DESCRIPTION = "A long rope."

# dining room trapdoor
DINING_ROOM_TRAPDOOR_NAME = "trapdoor"
DINING_ROOM_TRAPDOOR_DESCRIPTION = "A wooden trapdoor."

# dining room food
DINING_ROOM_FOOD_NAME = "breakfast"
DINING_ROOM_FOOD_DESCRIPTION = "A hearty breakfasat."
DINING_ROOM_FOOD_TASTE = "amazing"
DINING_ROOM_FOOD_SMELL = "A pleasent smell resembling eggs and bacon."

# dining room table
DINING_ROOM_TABLE_NAME = "table"
DINING_ROOM_TABLE_DESCRIPTION = "A round wooden table."

# dining room plate
DINING_ROOM_PLATE_NAME = "plate"
DINING_ROOM_PLATE_DESCRIPTION = "A ceramic plate."

# dining room fireplace
DINING_ROOM_FIREPLACE_NAME = "fireplace"
DINING_ROOM_FIREPLACE_DESCRIPTION = "A lit fireplace."
DINING_ROOM_FIREPLACE_SOUND = "The crackle of a fire."

# breakfast knife
BREAKFAST_KNIFE_NAME = "knife"
BREAKFAST_KNIFE_DESCRIPTION = "A small blunt knife."

# dining room crate
DINING_ROOM_CRATE_NAME = "crate"
DINING_ROOM_CRATE_DESCRIPTION = "A heavy crate filled to the brim with dirt."

# plate
PLATE_BREAKS = "The plate shatters into a dozen pieces."

#########################################################################

# bedroom
BEDROOM_NAME = "Bedroom"
BEDROOM_DESCRIPTION = "A room designed for humans to rest."
BEDROOM_BRIEF = "You are standig in a beautiful forest clearing with three beings infront of you. Their form is fuzzy and blurred and you can't make out their true appearence. They want to tell you something important but as they are about to do so you hear a distant clinking followed by a door knocking. You realize you're in a dream and you wake up covered in warm cozy bedsheets."

# bedroom key text
BEDROOM_KEY_TEXT = "B"

# pile of dust
BEDROOM_PILE_OF_DUST_NAME = "pile of dust"
BEDROOM_PILE_OF_DUST_DESCRIPTION = "A large pile of dust."

# bedroom button
BEDROOM_BUTTON_NAME = "button"
BEDROOM_BUTTON_DESCRIPTION = "A big decorated wooden button attached to the wall next to the bed."

# bed
BED_NAME = "bed"
BED_DESCRIPTION = "A comfy wooden red bed."

# bedroom door
BEDROOM_DOOR_NAME = "door"
BEDROOM_DOOR_DESCRIPTION = "A mundane wooden door."

# bedroom key
BEDROOM_KEY_NAME = "crude key"
BEDROOM_KEY_DESCRIPTION = "A key with a cursive letter B inscribed on it."

# bedroom hook
BEDROOM_HOOK_NAME = "hook"
BEDROOM_HOOK_DESCRIPTION = "A blunt wooden hook attached to the wall."

# bedroom rug
BEDROOM_RUG_NAME = "rug"
BEDROOM_RUG_DESCRIPTION = "A large soft red rug."

# bedroom button
BUTTON_LIGHTS_UP = "The button lights up."
BUTTON_GOES_DARK = "The button goes dark."
